
# Slot: phase


The phase for a coding sequence entity. For example, phase of a CDS as represented in a GFF3 with a value of 0, 1 or 2.

URI: [biolink:phase](https://w3id.org/biolink/vocab/phase)


## Domain and Range

[CodingSequence](CodingSequence.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [sequence localization attribute](sequence_localization_attribute.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
